| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Route53.Types.ResourceTagSet
Description
Synopsis
- data ResourceTagSet = ResourceTagSet' {
- resourceId :: Maybe Text
- resourceType :: Maybe TagResourceType
- tags :: Maybe (NonEmpty Tag)
- newResourceTagSet :: ResourceTagSet
- resourceTagSet_resourceId :: Lens' ResourceTagSet (Maybe Text)
- resourceTagSet_resourceType :: Lens' ResourceTagSet (Maybe TagResourceType)
- resourceTagSet_tags :: Lens' ResourceTagSet (Maybe (NonEmpty Tag))
Documentation
data ResourceTagSet Source #
A complex type containing a resource and its associated tags.
See: newResourceTagSet smart constructor.
Constructors
| ResourceTagSet' | |
Fields
| |
Instances
newResourceTagSet :: ResourceTagSet Source #
Create a value of ResourceTagSet with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:resourceId:ResourceTagSet', resourceTagSet_resourceId - The ID for the specified resource.
$sel:resourceType:ResourceTagSet', resourceTagSet_resourceType - The type of the resource.
- The resource type for health checks is
healthcheck. - The resource type for hosted zones is
hostedzone.
$sel:tags:ResourceTagSet', resourceTagSet_tags - The tags associated with the specified resource.
resourceTagSet_resourceId :: Lens' ResourceTagSet (Maybe Text) Source #
The ID for the specified resource.
resourceTagSet_resourceType :: Lens' ResourceTagSet (Maybe TagResourceType) Source #
The type of the resource.
- The resource type for health checks is
healthcheck. - The resource type for hosted zones is
hostedzone.
resourceTagSet_tags :: Lens' ResourceTagSet (Maybe (NonEmpty Tag)) Source #
The tags associated with the specified resource.