| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Route53.Types.Tag
Description
Documentation
A complex type that contains information about a tag that you want to add or edit for the specified health check or hosted zone.
See: newTag smart constructor.
Constructors
| Tag' | |
Fields
| |
Instances
| FromXML Tag Source # | |
| ToXML Tag Source # | |
Defined in Amazonka.Route53.Types.Tag | |
| Generic Tag Source # | |
| Read Tag Source # | |
| Show Tag Source # | |
| NFData Tag Source # | |
Defined in Amazonka.Route53.Types.Tag | |
| Eq Tag Source # | |
| Hashable Tag Source # | |
Defined in Amazonka.Route53.Types.Tag | |
| type Rep Tag Source # | |
Defined in Amazonka.Route53.Types.Tag type Rep Tag = D1 ('MetaData "Tag" "Amazonka.Route53.Types.Tag" "amazonka-route53-2.0-8wP357MyuPX6rh87d4wklb" 'False) (C1 ('MetaCons "Tag'" 'PrefixI 'True) (S1 ('MetaSel ('Just "key") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Maybe Text)) :*: S1 ('MetaSel ('Just "value") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Maybe Text)))) | |
Create a value of Tag with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:key:Tag', tag_key - The value of Key depends on the operation that you want to perform:
- Add a tag to a health check or hosted zone:
Keyis the name that you want to give the new tag. - Edit a tag:
Keyis the name of the tag that you want to change theValuefor. - Delete a key:
Keyis the name of the tag you want to remove. - Give a name to a health check: Edit the default
Nametag. In the Amazon Route 53 console, the list of your health checks includes a Name column that lets you see the name that you've given to each health check.
$sel:value:Tag', tag_value - The value of Value depends on the operation that you want to perform:
- Add a tag to a health check or hosted zone:
Valueis the value that you want to give the new tag. - Edit a tag:
Valueis the new value that you want to assign the tag.
tag_key :: Lens' Tag (Maybe Text) Source #
The value of Key depends on the operation that you want to perform:
- Add a tag to a health check or hosted zone:
Keyis the name that you want to give the new tag. - Edit a tag:
Keyis the name of the tag that you want to change theValuefor. - Delete a key:
Keyis the name of the tag you want to remove. - Give a name to a health check: Edit the default
Nametag. In the Amazon Route 53 console, the list of your health checks includes a Name column that lets you see the name that you've given to each health check.